# Generated by Django 4.0.9 on 2023-04-05 19:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0011_delete_duplicated_contracts"),
    ]

    operations = [
        migrations.AlterField(
            model_name="contract",
            name="contract_id",
            field=models.IntegerField(unique=True),
        ),
    ]
