# Generated by Django 4.0.6 on 2023-03-27 13:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0009_contract_location_name"),
    ]

    operations = [
        migrations.AddField(
            model_name="contract",
            name="no_tracking",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="tracking",
            name="tracking_number",
            field=models.CharField(max_length=32),
        ),
    ]
