# Generated by Django 4.0.6 on 2022-09-20 14:45

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0007_program_expiration"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access this app and see own statics."),
                    (
                        "manage_programs",
                        "Can manage own buyback programs and see own program statics.",
                    ),
                    (
                        "see_leaderboard",
                        "Can see leaderboards for all available programs.",
                    ),
                    (
                        "see_performance",
                        "Can see performance for all available programs.",
                    ),
                    ("see_all_statics", "Can see all program statics."),
                ),
            },
        ),
        migrations.AlterField(
            model_name="program",
            name="refining_rate",
            field=models.DecimalField(
                decimal_places=2,
                default=0,
                help_text="Refining rate to be used if ore refined value is active",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MaxValueValidator(100),
                    django.core.validators.MinValueValidator(0),
                ],
                verbose_name="Refining rate",
            ),
        ),
    ]
