# Generated by Django 4.0.4 on 2022-06-18 11:53

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0005_program_compression_price_dencity_modifier"),
    ]

    operations = [
        migrations.AddField(
            model_name="program",
            name="bonds_npc_price",
            field=models.BooleanField(
                default=False,
                help_text="Use NPC price as value for SCC Encrypted Bond",
                verbose_name="NPC price for: Bounty Encrypted Bonds",
            ),
        ),
        migrations.AlterField(
            model_name="program",
            name="discord_channel_notification",
            field=models.CharField(
                blank=True,
                help_text="Discord webhook to send contract notifications to.",
                max_length=256,
                null=True,
                verbose_name="Discord webhook for notifications",
            ),
        ),
        migrations.AlterField(
            model_name="program",
            name="location",
            field=models.ManyToManyField(
                help_text="The location where contracts should be created at.",
                related_name="+",
                to="buybackprogram.location",
            ),
        ),
    ]
