# Generated by Django 4.0.6 on 2022-09-09 14:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("buybackprogram", "0006_program_bonds_npc_price_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="program",
            name="expiration",
            field=models.CharField(
                choices=[
                    ("1 Day", "1 Day"),
                    ("3 Days", "3 Days"),
                    ("1 Week", "1 Week"),
                    ("2 Weeks", "2 Weeks"),
                    ("4 Weeks", "4 Weeks"),
                ],
                default="2 Weeks",
                help_text="Expiration time the contracts should bet set to.",
                max_length=7,
            ),
        ),
    ]
